@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.66 2004/01/26 18:59:19 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.70 2004/02/18 16:22:18 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -86,7 +86,7 @@ char *mstrs[] = {              /* Mode titles to be added to the titlebar. */
 
 
 char *ttype_str[] = {          /* Strings for each trig type value. */
-    N_("De_grees"), N_("Gr_adients"), N_("_Radians")
+    N_("De_grees"), N_("Gr_adians"), N_("_Radians")
 };
 
 char *ttype_desc[] = {         /* Tooltips for each trig type value. */
@@ -141,8 +141,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     N_("7"),
     NULL,
     N_("Numeric 7"),
-    { 0,     0,        0,           0,      0 },
-    { GDK_7, GDK_KP_7, GDK_KP_Home, GDK_R7, 0 },
+    { 0,     GDK_SHIFT_MASK, 0,        0,           0,      0 },
+    { GDK_7, GDK_7,          GDK_KP_7, GDK_KP_Home, GDK_R7, 0 },
     '7',
     M_NONE,
     do_number
@@ -151,8 +151,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     N_("8"),
     NULL,
     N_("Numeric 8"),
-    { 0,     0,        0,         0,      0 },
-    { GDK_8, GDK_KP_8, GDK_KP_Up, 0 },
+    { 0,     GDK_SHIFT_MASK, 0,        0,         0 },
+    { GDK_8, GDK_8,          GDK_KP_8, GDK_KP_Up, 0 },
     '8',
     M_NONE,
     do_number
@@ -161,8 +161,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     N_("9"),
     NULL,
     N_("Numeric 9"),
-    { 0,     0,        0,              0,      0 },
-    { GDK_9, GDK_KP_9, GDK_KP_Page_Up, GDK_R9, 0 },
+    { 0,     GDK_SHIFT_MASK, 0,        0,              0,      0 },
+    { GDK_9, GDK_9,          GDK_KP_9, GDK_KP_Page_Up, GDK_R9, 0 },
     '9',
     M_NONE,
     do_number
@@ -223,8 +223,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     N_("4"),
     NULL,
     N_("Numeric 4"),
-    { 0,     0,        0,           0,        0 },
-    { GDK_4, GDK_KP_4, GDK_KP_Left, 0 },
+    { 0,     GDK_SHIFT_MASK, 0,        0,           0 },
+    { GDK_4, GDK_4,          GDK_KP_4, GDK_KP_Left, 0 },
     '4',
     M_NONE,
     do_number
@@ -233,8 +233,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     N_("5"),
     NULL,
     N_("Numeric 5"),
-    { 0,     0,        0,            0,       0 },
-    { GDK_5, GDK_KP_5, GDK_KP_Begin, GDK_R11, 0 },
+    { 0,     GDK_SHIFT_MASK, 0,        0,            0,       0 },
+    { GDK_5, GDK_5,          GDK_KP_5, GDK_KP_Begin, GDK_R11, 0 },
     '5',
     M_NONE,
     do_number
@@ -243,8 +243,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     N_("6"),
     NULL,
     N_("Numeric 6"),
-    { 0,     0,        0,            0,         0 },
-    { GDK_6, GDK_KP_6, GDK_KP_Right, 0 },
+    { 0,     GDK_SHIFT_MASK, 0,        0,            0 },
+    { GDK_6, GDK_6,          GDK_KP_6, GDK_KP_Right, 0 },
     '6',
     M_NONE,
     do_number
@@ -305,8 +305,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     N_("1"),
     NULL,
     N_("Numeric 1"),
-    { 0,     0,        0,          0,       0 },
-    { GDK_1, GDK_KP_1, GDK_KP_End, GDK_R13, 0 },
+    { 0,     GDK_SHIFT_MASK, 0,        0,          0,       0 },
+    { GDK_1, GDK_1,          GDK_KP_1, GDK_KP_End, GDK_R13, 0 },
     '1',
     M_NONE,
     do_number
@@ -315,8 +315,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     N_("2"),
     NULL,
     N_("Numeric 2"),
-    { 0,     0,        0,           0,        0 }, 
-    { GDK_2, GDK_KP_2, GDK_KP_Down, 0 },
+    { 0,     GDK_SHIFT_MASK, 0,        0,           0 }, 
+    { GDK_2, GDK_2,          GDK_KP_2, GDK_KP_Down, 0 },
     '2',
     M_NONE,
     do_number
@@ -325,8 +325,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     N_("3"),
     NULL,
     N_("Numeric 3"),
-    { 0,     0,        0,                0,       0 },
-    { GDK_3, GDK_KP_3, GDK_KP_Page_Down, GDK_R15, 0 },
+    { 0,     GDK_SHIFT_MASK, 0,        0,                0,       0 },
+    { GDK_3, GDK_3,          GDK_KP_3, GDK_KP_Page_Down, GDK_R15, 0 },
     '3',
     M_NONE,
     do_number
@@ -387,8 +387,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     N_("0"),
     NULL,
     N_("Numeric 0"),
-    { 0,     0,        0,             0 },
-    { GDK_0, GDK_KP_0, GDK_KP_Insert, 0 },
+    { 0,     GDK_SHIFT_MASK, 0,        0,             0 },
+    { GDK_0, GDK_0,          GDK_KP_0, GDK_KP_Insert, 0 },
     '0',
     M_NONE,
     do_number
@@ -434,7 +434,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     do_immed
 },
 {
-    N_("x<sup><i>2</i></sup>"),
+    N_("<i>x</i><sup>2</sup>"),
     N_("Square"),
     NULL,
     { GDK_SHIFT_MASK, 0 },
@@ -790,7 +790,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     do_immed
 },       
 {        
-    N_("x<sup><i>y</i></sup>"),
+    N_("<i>x</i><sup><i>y</i></sup>"),
     N_("Raise displayed value to the power of y"),
     N_("X to the y"),
     { 0, 0 },   
