@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/functions.c,v 1.37 2004/02/04 00:00:12 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/functions.c,v 1.38 2004/02/17 17:25:44 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -504,7 +504,8 @@ do_factorial(int *MPval, int *MPres)
                 mpmuli(MPa, &i, MPa);
                 mpcmd(MPa, &val);
                 if (v->error) {
-                    break;
+                    mperr();
+                    return;
                 }
                 i--;
             }
